# Changelog

<!--next-version-placeholder-->

## v0.1.2 (2023-04-11)
### Fix
* **deps:** Remove `pip.install-pip-tools` since that is a dependency of the plugin already ([`52a0658`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/52a0658d89e60bbc7a6ef972fc2638105090fa91))

### Documentation
* **readme:** Reference to changelog ([`0c28681`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/0c28681f36f56096cddf2cf0e7728a21b96fd42d))
* **changelog:** Manual fix changelog for missing version ([`0bce078`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/0bce078164b04ec93e26927294edf1a3daa76334))

## v0.1.1 (2023-04-11)
### Feature
* initial version of this plugin. ([`5624dd9`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/5624dd982dd0b1362616c2796209a1365fe966eb))
